@@ -248,7 +248,7 @@ def show_workflow(actions, all=False, language=None):
     return doit()
 
 
-def show_fields(model, fieldnames=None, columns=False, all=None):
+def fields_help(model, fieldnames=None, columns=False, all=None):
     """
     Print an overview description of the specified fields of the
     specified model.
@@ -290,6 +290,8 @@ def show_fields(model, fieldnames=None, columns=False, all=None):
             get_field = model.parameters.get
             if fieldnames is None:
                 fieldnames = model.params_layout.main
+    if fieldnames is None:
+        return
     if isinstance(fieldnames, str):
         fieldnames = fieldnames.split()
     for n in fieldnames:
@@ -301,7 +303,10 @@ def show_fields(model, fieldnames=None, columns=False, all=None):
                               fld.verbose_name,
                               unindent(ht)])
 
-    print(table(cols, cells).strip())
+    return table(cols, cells).strip()
+
+def show_fields(*args, **kwargs):
+    print(fields_help(*args, **kwargs))
 
 def show_fields_by_type(fldtype):
     """Print a list of all fields (in all models) that have the specified type.
@@ -504,7 +509,7 @@ def show_dashboard(username, **options):
     """
     request = PseudoRequest(username)
     ui = settings.SITE.kernel.text_renderer.front_end
-    html = settings.SITE.get_main_html(request, extjs=ui)
+    html = settings.SITE.get_main_html(request, front_end=ui)
     print(html2text(html, **options))
 
 def menu2rst(mnu, level=1):
