@@ -11,6 +11,7 @@ import logging; logger = logging.getLogger(__name__)
 
 from django.utils.translation import gettext_lazy as _
 from django.utils.translation import gettext
+from django.utils.translation import get_language
 from django.utils.text import format_lazy
 from django.utils.encoding import force_str
 from django.conf import settings
@@ -43,6 +44,37 @@ def discover_choosers():
             check_for_chooser(model, field)
         # ~ logger.debug("Discovered %d choosers in model %s.",n,model)
 
+def resolve_layout(cls, k, spec, layout_class, **options):
+    # k: just for naming the culprit in error messages
+    if isinstance(spec, str):
+        if '\n' in spec or not '.' in spec:
+            return layout_class(spec, cls, **options)
+        else:
+            layout_class = settings.SITE.models.resolve(spec)
+            if layout_class is None:
+                raise Exception("Unresolved {} {!r} for {}".format(k, spec, cls))
+            return layout_class(None, cls, **options)
+    elif isinstance(spec, layouts.Panel):
+        options.update(spec.options)
+        return layout_class(spec.desc, cls, **options)
+    else:
+        if not isinstance(spec, layout_class):
+            if not isinstance(cls, type):
+                # cls is an action instance
+                cls = cls.__class__
+            msg = "{}.{}.{} must be a string, " \
+                  "a Panel or an instance of {} (not {!r})"
+            raise Exception(msg.format(
+                cls.__module__, cls.__name__, k, layout_class.__name__, spec))
+        if spec._datasource is None:
+            spec.set_datasource(cls)
+            return spec
+        elif not issubclass(cls, spec._datasource):
+            raise Exception(
+                "Cannot reuse %s instance (%s of %r) for %r" %
+                (spec.__class__, k, spec._datasource, cls))
+    return spec
+
 
 def install_layout(cls, k, layout_class, **options):
     """
@@ -58,33 +90,7 @@ def install_layout(cls, k, layout_class, **options):
         dl = getattr(cls, k, None)
     if dl is None:
         return
-    if isinstance(dl, str):
-        if '\n' in dl or not '.' in dl:
-            setattr(cls, k, layout_class(dl, cls, **options))
-        else:
-            layout_class = settings.SITE.models.resolve(dl)
-            if layout_class is None:
-                raise Exception("Unresolved {} {!r} for {}".format(k, dl, cls))
-            setattr(cls, k, layout_class(None, cls, **options))
-    elif isinstance(dl, layouts.Panel):
-        options.update(dl.options)
-        setattr(cls, k, layout_class(dl.desc, cls, **options))
-    else:
-        if not isinstance(dl, layout_class):
-            if not isinstance(cls, type):
-                # cls is an action instance
-                cls = cls.__class__
-            msg = "{}.{}.{} must be a string, " \
-                  "a Panel or an instance of {} (not {!r})"
-            raise Exception(msg.format(
-                cls.__module__, cls.__name__, k, layout_class.__name__, dl))
-        if dl._datasource is None:
-            dl.set_datasource(cls)
-            setattr(cls, k, dl)
-        elif not issubclass(cls, dl._datasource):
-            raise Exception(
-                "Cannot reuse %s instance (%s of %r) for %r" %
-                (dl.__class__, k, dl._datasource, cls))
+    setattr(cls, k, resolve_layout(cls, k, dl, layout_class, **options))
 
 
 def register_params(cls):
@@ -99,9 +105,9 @@ def register_params(cls):
             # v.model = cls  # 20181023 experimentally
 
         if cls.params_layout is None:
-            cls.params_layout = cls._layout_class.join_str.join(
+            cls.params_layout = cls._params_layout_class.join_str.join(
                 cls.parameters.keys())
-        install_layout(cls, 'params_layout', cls._layout_class)
+        install_layout(cls, 'params_layout', cls._params_layout_class)
 
     # e.g. ledger.ByJournal is just a mixin but provides a default value for its children
     elif cls.params_layout is not None:
@@ -145,7 +151,7 @@ class Action(Parametrizable, Permittable):
 
     """
     # ~ __metaclass__ = ActionMetaClass
-    _layout_class = layouts.ActionParamsLayout
+    _params_layout_class = layouts.ActionParamsLayout
 
     label = None
     button_text = None
@@ -471,6 +477,9 @@ class Action(Parametrizable, Permittable):
         return InstanceAction(
             self, instance.get_default_table(), instance, owner)
 
+    def get_a_href_target(self):
+        return None
+
     def get_django_form(self):
         """returns a django form object based on the params of this action"""
         from django import forms
@@ -802,11 +811,14 @@ class ShowDetail(Action):
         return self.owner.required_roles
 
     def get_window_layout(self, actor):
+        # if actor.detail_layout is None:
+        #     return actor.extra_layouts[0]
         return actor.detail_layout
 
     def get_window_size(self, actor):
         wl = self.get_window_layout(actor)
-        return wl.window_size
+        if wl is not None:
+            return wl.window_size
 
 
 class ShowEmptyTable(ShowDetail):
@@ -817,7 +829,7 @@ class ShowEmptyTable(ShowDetail):
     action_name = 'show'
     default_format = 'html'
     icon_name = None
-    callable_from = 't'
+    # callable_from = 't'
     hide_navigator = True  # 20210509
 
     # def attach_to_actor(self, actor, name):
@@ -831,6 +843,15 @@ class ShowEmptyTable(ShowDetail):
         return super(ShowEmptyTable, self).as_bootstrap_html(ar, '-99998')
 
 
+class ShowExtraDetail(ShowEmptyTable):
+    # label = None
+    # def get_label(self):
+    #     return None
+
+    def get_window_layout(self, actor):
+        return self.owner
+
+
 class ShowInsert(TableAction):
     save_action_name = 'submit_insert'
     show_in_plain = True
@@ -878,7 +899,8 @@ class ShowInsert(TableAction):
 
     def get_window_size(self, actor):
         wl = self.get_window_layout(actor)
-        return wl.window_size
+        if wl is not None:
+            return wl.window_size
 
     def get_view_permission(self, user_type):
         # the action is readonly because it doesn't write to the
@@ -1157,6 +1179,41 @@ class ShowSlaveTable(Action):
         ar.set_response(eval_js=js)
 
 
+class QuickLinkAction(Action):
+
+    instance = None  # for Renderer.menu_item_button()
+    show_in_bbar = True
+    callable_from = 'd'
+
+    WRAPPED_ATTRS = ('help_text', 'icon_name', 'react_icon_name', 'label',
+                     'sort_index', 'required_roles', 'button_text')
+
+    def __init__(self, bound_action, **kwargs):
+        self.bound_action = bound_action
+        kwargs.update(action_name=str(bound_action.actor)+'_'+bound_action.action.action_name)
+        for k in self.WRAPPED_ATTRS:
+            if k not in kwargs:
+                kwargs[k] = getattr(bound_action.action, k)
+        super(QuickLinkAction, self).__init__(**kwargs)
+
+    def get_required_roles(self, actor):
+        # print(self.bound_action, actor.required_roles | self.bound_action.required)
+        return actor.required_roles | self.bound_action.required
+
+    @classmethod
+    def get_actor_label(self):
+        return self.get_label() or self.bound_action.label
+
+    def get_label(self):
+        return self.label or str(self.bound_action.action)
+
+    def run_from_ui(self, ar, **kw):
+        sar = self.bound_action.request_from(ar)
+        js = ar.renderer.request_handler(sar)
+        ar.set_response(eval_js=js)
+
+
+
 class MultipleRowAction(Action):
     """Base class for actions that update something on every selected row.
     """
@@ -1297,3 +1354,17 @@ def get_view_permission(e):
             return False  # bug 3 (bcss_summary) blog/2012/0927
         parent = parent.parent
     return True
+
+
+class OpenHelpWindow(Action):
+
+    action_name = 'open_help'
+    # icon_name = 'help'
+    button_text = '?'
+
+    def get_a_href_target(self):
+        parts = ['cache', 'help']
+        if get_language() != settings.SITE.DEFAULT_LANGUAGE.django_code:
+            parts.append(get_language())
+        parts.append("index.html")
+        return settings.SITE.build_media_url(*parts)
