@@ -307,11 +307,11 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 
     """
 
-    actions = None
-    """An :class:`AttrDict <atelier.utils.AttrDict>` containing the
-    actions available on this actor.
-
-    """
+    # actions = None
+    # """An :class:`AttrDict <atelier.utils.AttrDict>` containing the
+    # actions available on this actor.
+    #
+    # """
 
     only_fields = None
 
@@ -327,6 +327,8 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     :func:`lino.core.table.table_factory` also uses this.
     """
 
+    open_help = actions.OpenHelpWindow()
+
     master = None
     """The class of the "master" for this actor.
 
@@ -364,7 +366,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     parameters = None
     # See :attr:`lino.core.utils.Parametrizable.parameters`.
 
-    _layout_class = layouts.ParamsLayout
+    _params_layout_class = layouts.ParamsLayout
     _state_to_disabled_actions = None
 
     ignore_required_states = False
@@ -770,16 +772,24 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 
     @classmethod
     def init_layouts(cls):
-
         # 20200430 this was previously part of class_init, but is now called in
         # a second loop. Because calview.EventsParams copies parameters from Events.
-
         actions.install_layout(cls, 'detail_layout', layouts.DetailLayout)
         actions.install_layout(cls, 'insert_layout', layouts.InsertLayout,
             window_size=(cls.insert_layout_width, 'auto'))
         actions.install_layout(cls, 'card_layout', layouts.DetailLayout)
         actions.install_layout(cls, 'item_layout', layouts.DetailLayout)
 
+        cls.extra_layouts = []
+        for name, main in cls.get_extra_layouts():
+            layout_instance = actions.resolve_layout(
+                cls, 'extra_layout', main, layouts.DetailLayout)
+            cls.extra_layouts.append(layout_instance)
+            a = actions.ShowExtraDetail(layout_instance)
+            cls._bind_action("extra_"+name, a, False)
+            if cls.detail_action is None:
+                cls.detail_action = cls._bind_action('detail_action', a, True)
+
         if cls.abstract:
             return
 
@@ -1073,6 +1083,8 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
                             if k not in required_states:
                                 st2da[k].add(ba.action.action_name)
 
+    def collect_extra_actions():
+        return []
 
     @classmethod
     def _bind_action(cls, k, a, override):
@@ -1508,10 +1520,11 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         Return a list of actions for which a button should exist in the
         toolbar of the specified "parent" action.
         """
-        tba = [ba for ba in self.get_button_actions(parent)
-                if ba.action.show_in_bbar and (
-                    ba.action.readonly or not self.hide_editing(user_type))]
-        return tba
+
+        for ba in self.get_button_actions(parent):
+            if ba.action.show_in_bbar and ba.get_view_permission(user_type):
+                if ba.action.readonly or not self.hide_editing(user_type):
+                    yield ba
 
     # @classmethod
     # def get_cell_context_actions(self, cf):
@@ -1566,17 +1579,22 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     @classmethod
     def get_detail_elems(cls, *args):
         """
+        Return a list of the widgets (layout elements) that make up
+        the detail layout.
+
         An optional first argument is the front end plugin, a
         :class:`Plugin` instance.  If this is None, use
         :attr:`settings.SITE.kernel.default_ui
         <lino.core.kernel.Kernel.default_ui>`.
 
-        Returns a list of the widgets (layout elements) that make up
-        the detail layout.
         """
         lh = cls.get_detail_layout(*args)
         return lh.main.elements
 
+    @classmethod
+    def get_extra_layouts(cls):
+        return []
+
     @classmethod
     def get_data_elem(self, name):
         """Find data element in this actor by name.
@@ -1765,7 +1783,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 def resolve_action(spec, action=None):
     givenspec = spec
 
-    if is_string(spec):
+    if isinstance(spec, str):
         site = settings.SITE
         # if spec.startswith('webshop.'):
         #     print("20210320", spec, repr(site.models.resolve(spec)))
