@@ -296,18 +296,19 @@ class Kernel(object):
                             f.remote_field, f.remote_field.model))
                     f.remote_field.model._lino_ddh.add_fk(m or model, f)
 
-            fieldnames = {f.name for f in model._meta.get_fields()}
-            # print("20190627 checking ", model, fieldnames)
-            for m, k, v in class_dict_items(model):
-                if isinstance(v, fields.VirtualField) and k in fieldnames:
-                    f = model._meta.get_field(k)
-                    if f.__class__ is v.__class__:
-                        # a copy of the virtual field in parent has already been attached
-                        # print("20190627 ignoring", m, k, v, f)
-                        continue
-                    raise ChangedAPI(
-                        "{} field {}.{} hidden by virtual field of same name.".format(
-                            f.__class__.__name__, fmn(model), k))
+            if not site.quick_startup:
+                fieldnames = {f.name for f in model._meta.get_fields()}
+                # print("20190627 checking ", model, fieldnames)
+                for m, k, v in class_dict_items(model):
+                    if isinstance(v, fields.VirtualField) and k in fieldnames:
+                        f = model._meta.get_field(k)
+                        if f.__class__ is v.__class__:
+                            # a copy of the virtual field in parent has already been attached
+                            # print("20190627 ignoring", m, k, v, f)
+                            continue
+                        raise ChangedAPI(
+                            "{} field {}.{} hidden by virtual field of same name.".format(
+                                f.__class__.__name__, fmn(model), k))
 
         self.protect_foreignkeys(models_list)
 
@@ -395,6 +396,7 @@ class Kernel(object):
             #     raise # Exception("Failed to class_init {} : {}".format(a, e))
 
 
+
         for a in actors.actors_list:
             a.init_layouts()
 
@@ -488,6 +490,15 @@ class Kernel(object):
 
         # web.site_setup(site)
 
+        for a in actors.actors_list:
+            for i, ea in enumerate(a.collect_extra_actions()):
+                a._bind_action(ea.action_name, ea, False)
+                # ba = actors.resolve_action(ba)
+                # ba = mi.bound_action
+                # a._bind_action(ba.full_name(),
+                #     actions.QuickLinkAction(ba, label=mi.label), False)
+                # print("20210602", new_ba.required)
+
         for a in actors.actors_list:
 
             site.install_help_text(a)
