@@ -1,5 +1,5 @@
 # Copyright 2009-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """See :doc:`/dev/layouts/index`.
 
@@ -9,7 +9,7 @@ import logging ; logger = logging.getLogger(__name__)
 import re
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.db.models.fields import NOT_PROVIDED
 from django.db.models.fields.related import ForeignObject
 # from django.contrib.contenttypes.fields import GenericRelation
@@ -17,6 +17,7 @@ from django.db.models.fields.related import ForeignObject
 from lino.core import constants
 from lino.core.fields import fields_list, VirtualField, wildcard_data_elems
 from lino.core.plugin import Plugin
+from lino.modlib.users.utils import get_user_profile
 
 
 class LayoutError(RuntimeError):
@@ -408,10 +409,10 @@ class BaseLayout(object):
 
     """
 
-    editable = True
-    """Lino sets this to False for layouts on a non-editable actor.
-
-    """
+    # editable = True
+    # """Lino sets this to False for layouts on a non-editable actor.
+    #
+    # """
 
     main = None
     """The description of the main element of this layout.
@@ -435,7 +436,7 @@ class BaseLayout(object):
         """
         self._labels = self.override_labels()
         self._added_panels = dict()
-        self._other_datasources = set()
+        self._other_datasources = []
         self.hidden_elements = hidden_elements or set()
         self._element_options = dict()
         if main is not None:
@@ -463,6 +464,11 @@ class BaseLayout(object):
             self.__class__.__module__, self.__class__.__name__,
             self._datasource)
 
+    def add_datasource(self, ds):
+        if ds in self._other_datasources:
+            return
+        self._other_datasources.append(ds)
+
     def set_datasource(self, ds):
         self._datasource = ds
         if ds is not None:
@@ -470,10 +476,21 @@ class BaseLayout(object):
                 self.hidden_elements = set(fields_list(
                     ds, self.hidden_elements))
             self.hidden_elements |= ds.hidden_elements
-            self.editable = ds.editable
+            # self.editable = not ds.hide_editing(user_type)
             #~ if str(ds).endswith('Partners'):
                 #~ print "20130124 set_datasource ", self,self.hidden_elements
 
+    @property
+    def editable(self):
+        # return False when actor.hide_editing()
+        return not self._datasource.hide_editing(get_user_profile())
+
+    def get_datasources(self):
+        # used by Course.get_detail_action
+        yield self._datasource
+        for ds in self._other_datasources:
+            yield ds
+
     def get_chooser_holder(self):
         return self._datasource
 
@@ -602,7 +619,8 @@ add_tabpanel() on %s horizontal 'main' panel %r."""
 
     def get_layout_handle(self, ui=None):
         """
-        `ui` is a :class:`Plugin` instance.
+        Return the LayoutHandle for this layout on the specified front end `ui`.
+        Create a LayoutHandle instance if this is the first call.        
         """
         if ui is None:
             ui = settings.SITE.kernel.default_ui
