@@ -11,6 +11,18 @@ from django.conf import settings
 from lino.core.utils import obj2str
 from lino.core.actors import resolve_action
 from lino.core.boundaction import BoundAction
+from lino.core.actions import QuickLinkAction
+
+
+class QuickLinksList:
+
+    def __init__(self):
+        self.items = []
+
+    def add_action(self, ba, **kwargs):
+        ba = resolve_action(ba)
+        a = QuickLinkAction(ba, **kwargs)
+        self.items.append(a)
 
 
 class MenuItem(object):
