@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2008-2019 Rumma & Ko Ltd
-# License: BSD, see LICENSE for more details.
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This defines the :class:`Plugin` class.
 
@@ -229,8 +229,7 @@ class Plugin(object):
         Note that only the app_label (not the whole plugin name) is used when
         testing whether a plugin is installed. IOW if a plugin says it requires
         a plugin "stdlib.foo" and an application already has some plugin
-        "mylib.foo" installed, "mylib" satisfies "stdlib.foo".
-
+        "mylib.foo" installed, then "mylib.foo" satisfies "stdlib.foo".
 
         """
 
@@ -419,16 +418,24 @@ class Plugin(object):
         """
         pass
 
-    def get_quicklinks(self, user):
-        """Return or yield a sequence of actions of the "quick links" toolbar.
+    def get_quicklinks(self):
+        """
 
-        Called by :meth:`lino.core.site.Site.setup_quicklinks`.
+        Return or yield a sequence of quick link descriptors to be added to the
+        list of quick links.
+
+        A :term:`quick link` descriptor is a string that identifies either an
+        actor or a bound action.
 
-        Every item is expected to be a subclass of
-        :class:`lino.core.actors.Actor`.
         """
         return []
 
+    def setup_quicklinks(self, tb):
+        """
+        Add quicklinks to the list of quick links.
+        """
+        pass
+
     def get_dashboard_items(self, user):
         """Return or yield a sequence of items to be rendered on the
         dashboard.
