@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2009-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 See introduction in :doc:`/dev/ar`.
 """
@@ -11,8 +11,8 @@ from copy import copy
 from xml.sax.saxutils import escape
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ugettext as gettext
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import gettext
 from django.utils.translation import get_language, activate
 from django.utils import translation
 from django.utils import timezone
@@ -113,11 +113,11 @@ class ValidActionResponses(object):
 
     xcallback = None
     """
-    Used for dialogs asking simple yes/no/later style question
-    Includes all the data the client needs inorder to send the same action
+    Used for dialogs asking simple yes/no/later style questions.
+    Includes all the data the client needs in order to send the same action
     request again, but with some extra confirmation values.
 
-    is a dict which includes the following values:
+    Is a dict which includes the following values:
 
     - actor_id : The id of the actor
     - an : The action name of the action which was run
@@ -357,8 +357,8 @@ class BaseRequest(object):
 
 
 
-        kw.update(xcallback_answers={id: rqdata[id] for id in [callbackID for callbackID in rqdata.keys() if
-                                                               callbackID.startswith("xcallback__")]})
+        kw.update(xcallback_answers={id: rqdata[id] for id in [
+            callbackID for callbackID in rqdata.keys() if callbackID.startswith("xcallback__")]})
 
         #~ if settings.SITE.user_model:
             #~ username = rqdata.get(constants.URL_PARAM_SUBST_USER,None)
@@ -437,7 +437,7 @@ class BaseRequest(object):
         documents.
         """
         # from django.conf import settings
-        from django.utils.translation import ugettext
+        from django.utils.translation import gettext
         from django.utils.translation import pgettext
         from lino.api import dd, rt
         from lino.utils import iif
@@ -456,7 +456,7 @@ class BaseRequest(object):
         else:
             kw['ar'] = self
 
-        kw['_'] = ugettext
+        kw['_'] = gettext
         kw.update(
             E=E, tostring=tostring,
             dd=dd,
@@ -606,7 +606,11 @@ class BaseRequest(object):
         Tell the client to consider the action as successful. This is the
         same as :meth:`set_response` with `success=True`.
 
-        First argument should be a textual message.
+        First argument should be a translatable message.
+
+        If you want the message to be shown as an alert message, specify
+        `alert=True`.
+
         """
         kw.update(success=True)
         if alert is not None:
@@ -662,19 +666,26 @@ class BaseRequest(object):
         Execute the specified callable `ok_func` after the user has
         confirmed the specified message.
 
-        The confirmation message may be specified as a series of
-        positional arguments which will be concatenated to a single
-        prompt.
+        The confirmation message may be specified as a series of positional
+        arguments, which will be concatenated to a single prompt.
 
-        The callable will be called with a single positional argument
-        which will be the action request that confirmed the
-        message. In a web context this will be another object than
-        this one.
+        Pitfall: an action that uses :meth:`ar.confirm
+        <lino.core.requests.BaseRequest.confirm>` will be called several times,
+        once for each call to :meth:`confirm`. The full text of the confirmation
+        message must remain the same each time because it serves as the
+        identifier for connecting the two AJAX requests. If the action does
+        changes to the database before its last call to :meth:`confirm`, it must
+        take care to actually do them only when :attr:`xcallback_answers` is an
+        empty `dict`.
+
+        The callable will be called with a single positional argument, which
+        will be the action request that confirmed the message. In a web context
+        this will be another object than this one.
 
         In a non-interactive renderer (e.g. in a doctest or when using #
         :class:`lino.core.renderer.TestRenderer`) the `ok_func` function (or
         :func:`noop`) is called directly depending on the value of
-        :attr:`_confirm_answer` which potentially has been set by a previous
+        :attr:`_confirm_answer`, which potentially has been set by a previous
         call to :meth:`set_confirm_answer`.
 
         """
@@ -715,23 +726,27 @@ class BaseRequest(object):
     def goto_instance(self, *args, **kwargs):
         return self.renderer.goto_instance(self, *args, **kwargs)
 
-    def goto_pk(self, pk, *args, **kwargs):
+    def goto_pk(self, pk, text, **kwargs):
         """Navigate to the record with the specified primary key.
 
-        This is similar to :meth:`goto_instance` but works only in a detail
-        view.  It has the advantage of not doing permission checks and no
-        database lookup just for rendering a link. """
+        When `pk`  is `None`, returns just the text.
+        The `text` argument is mandatory.
+
+        This is similar to :meth:`goto_instance`, but is more lightweight (does
+        not do permission checks and no database lookup) and therefore works
+        only in a detail view.
+
+        """
 
         r = self.renderer
+        if pk is None:
+            return text
         if r.extjs_version:
             url = r.js2url("Lino.goto_record_id(%s)" % pk)
         else:
             url = self.get_detail_url(self.actor, pk)
-        return r.href(url, *args, **kwargs)
-        # ba = self.actor.detail_action
-        # js = self.renderer.action_call(self, ba, dict(record_id=pk))
-        # kwargs.update(eval_js=js)
-        # self.set_response(**kwargs)
+        return r.href(url, text, **kwargs)
+
 
     def close_window(self, **kw):
         """Ask client to close the current window. This is the same as
@@ -905,34 +920,20 @@ class BaseRequest(object):
         """
         return self.renderer.show_story(self, *args, **kwargs)
 
-    def show_dashboard(self):
-        """Show the dashboard of the user who made this request.
+    # def show_dashboard(self):  moved to lino.api.doctest
 
-        Utility method for doctests."""
+        # for i in self.get_user().get_preferences().dashboard_items:
+        #     print(i)
 
-        if self.renderer.hide_dashboard_items:
-            return ""
-        else:
-            return self.show_story(
-                self.get_user().get_preferences().dashboard_items)
-
-    def show_menu(self, language=None, **kwargs):
-        """Show the main menu for the requesting user using the requested
-        renderer.
-
-        This is used in tested docs.
-
-        :language: explicitly select another language than that
-                   specified in the requesting user's :attr:`language
-                   <lino.modlib.users.models.User.language>` field.
-
-        """
-        user = self.get_user()
-        if language is None:
-            language = user.language
-        with translation.override(language):
-            mnu = settings.SITE.get_site_menu(user.user_type)
-            self.renderer.show_menu(self, mnu, **kwargs)
+        # if self.renderer.hide_dashboard_items:
+        #     return ""
+        # else:
+            # chunks = []
+            # for i in self.get_user().get_preferences().dashboard_items:
+            #     chunks.extend(i.render(self))
+            # return ''.join(chunks)
+        # return self.show_story(
+        #     self.get_user().get_preferences().dashboard_items)
 
     def get_home_url(self, *args, **kw):
         """Return URL to the "home page" as defined by the renderer, without
@@ -1048,7 +1049,8 @@ class BaseRequest(object):
         cls = self.actor
         buttons = []
         if cls is not None:
-            for ba in cls.get_toolbar_actions(self.bound_action.action):
+            user_type = self.get_user().user_type
+            for ba in cls.get_toolbar_actions(self.bound_action.action, user_type):
                 if not ba.action.select_rows:
                     if ba.action.show_in_plain:
                         ir = ba.request_from(self)
@@ -1154,7 +1156,7 @@ class BaseRequest(object):
             #            ar.get_detail_title(elem))
         rec.update(id=elem.pk)
         # rec.update(id=ar.actor.get_pk_field().value_from_object(elem))
-        if ar.actor.editable:
+        if not ar.actor.hide_editing(ar.get_user().user_type):
             rec.update(disable_delete=rh.actor.disable_delete(elem, ar))
         if rh.actor.show_detail_navigator and with_navinfo:
             rec.update(navinfo=rh.actor.get_navinfo(ar, elem))
@@ -1251,7 +1253,7 @@ class ActorRequest(BaseRequest):
         #    and not self.actor.stay_in_grid \
         #    and not self.actor.force_phantom_row:
         #     return
-        if self.create_kw is None or not self.actor.editable \
+        if self.create_kw is None or self.actor.hide_editing(self.get_user().user_type) \
                 or not self.actor.allow_create:
             return
         if not self.actor.get_create_permission(self):
