@@ -607,7 +607,7 @@ class Parametrizable(object):
     params_panel_pos = "top"  # allowed values "top", "bottom", "left" and "right"
     use_detail_param_panel = False
 
-    _layout_class = NotImplementedError
+    _params_layout_class = NotImplementedError
 
     def get_window_layout(self, actor):
         return self.params_layout
