@@ -1,19 +1,17 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-"""Defines the model mixins :class:`Sequenced` and
-:class:`Hierarchical`.
+"""
+Defines the model mixins :class:`Sequenced` and :class:`Hierarchical`.
 
 A `Sequenced` is something which has a sequence number and thus a sort
-order which can be manipulated by the user using actions
+order which can be manipulated by the :term:`end user` using actions
 :class:`MoveUp` and :class:`MoveDown`.
 
 :class:`Hierarchical` is a :class:`Sequenced` with a `parent` field.
 
 """
 
-# from builtins import object
-
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 from django.core.exceptions import ValidationError
@@ -32,7 +30,7 @@ class MoveByN(actions.Action):
     """Move this row N rows upwards or downwards.
 
     This action is available on any :class:`Sequenced` object as
-    :attr:`Sequenced.MoveByN`.
+    :attr:`Sequenced.move_by_n`.
 
     It is currently only used by React to allow for drag and drop reording.
 
@@ -54,7 +52,7 @@ class MoveByN(actions.Action):
             return False
         if not super(MoveByN, self).get_action_permission(ar, obj, state):
             return False
-        if ar.data_iterator.count() == 0:
+        if ar.get_total_count() == 0:
             return False
         return True
 
@@ -94,7 +92,7 @@ class MoveUp(actions.Action):
             return False
         if not super(MoveUp, self).get_action_permission(ar, obj, state):
             return False
-        if ar.data_iterator.count() == 0:
+        if ar.get_total_count() == 0:
             return False
         if ar.data_iterator[0] == obj:
             return False
@@ -135,9 +133,10 @@ class MoveDown(actions.Action):
             return False
         if not super(MoveDown, self).get_action_permission(ar, obj, state):
             return False
-        if ar.data_iterator.count() == 0:
+        n = ar.get_total_count()
+        if n == 0:
             return False
-        if ar.data_iterator[ar.data_iterator.count() - 1] == obj:
+        if ar.data_iterator[n - 1] == obj:
             return False
         #~ if obj.__class__.__name__=='Entry' and obj.seqno == 25:
             #~ print 20130706, ar.data_iterator.count(), ar.data_iterator
@@ -204,13 +203,15 @@ class Sequenced(Duplicable):
         - :attr:`move_up` and :attr:`move_down`
         - duplicate
 
+    .. attribute:: move_by_n
+
     """
 
     move_action_names = ('move_up', 'move_down', 'duplicate')
     """The names of the actions to display in the `move_buttons`
     column.
 
-    Overridded by :class:`lino.modlib.notify.models.Widget` where the
+    Overridden by :class:`lino.modlib.dashboard.Widget` where the
     duplicate button would be irritating.
 
     """
@@ -219,7 +220,6 @@ class Sequenced(Duplicable):
         abstract = True
         ordering = ['seqno']
 
-    # seqno = models.IntegerField(_("Seq.No."), blank=True, null=False)
     seqno = models.IntegerField(_("No."), blank=True, null=False)
 
     duplicate = DuplicateSequenced()
@@ -334,7 +334,6 @@ class Sequenced(Duplicable):
                 l.append(' ')
         return E.p(*l)
 
-
 Sequenced.set_widget_options('move_buttons', width=5)
 Sequenced.set_widget_options('seqno', hide_sum=True)
 
@@ -344,6 +343,10 @@ class Hierarchical(Duplicable):
 
     Pronounciation: [hai'ra:kikl]
 
+    .. attribute:: children_summary
+
+        A comma-separated list of the children.
+
     """
     class Meta(object):
         abstract = True
