@@ -331,7 +331,7 @@ class Index(View):
 def index_response(ar):
     ui = settings.SITE.plugins.bootstrap3
 
-    main = settings.SITE.get_main_html(ar.request, extjs=ui)
+    main = settings.SITE.get_main_html(ar.request, front_end=ui)
     main = ui.renderer.html_text(main)
     context = dict(
         title=settings.SITE.title,
