@@ -444,7 +444,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             items=dashboard,
         )
         if not on_ready:
-            html = site.get_main_html(request, extjs=self.front_end)
+            html = site.get_main_html(request, front_end=self.front_end)
             html = self.html_text(html)
             dashboard.update(html=html)
 
@@ -482,8 +482,10 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             yield "Lino.user = %s;" % py2js(
                 dict(id=user.id, name=str(user)))
 
-            a = rt.models.users.MySettings.default_action
-            handler = self.action_call(None, a, dict(record_id=user.pk))
+            # a = rt.models.users.MySettings.default_action
+            # handler = self.action_call(None, ba, dict(record_id=user.pk))
+            ba = rt.models.users.Me.default_action
+            handler = self.action_call(None, ba, {})
             handler = "function(){%s}" % handler
             mysettings = dict(text=_("My settings"),
                               handler=js_code(handler))
@@ -505,7 +507,8 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
 
             if site.remote_user_header is None:
                 # 20170921
-                a = rt.models.users.MySettings.get_action_by_name('sign_out')
+                # a = rt.models.users.MySettings.get_action_by_name('sign_out')
+                a = rt.models.users.Me.get_action_by_name('sign_out')
                 # a = user.sign_out.bound_action
                 js = self.action_call(None, a, {})
                 js = "function(){%s}" % js
@@ -606,10 +609,13 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         actors_list = [
             a for a in self.actors_list if a.get_handle_name is None]
 
+        # for a in actors_list:
+        #     if a.default_action is None:
+        #         raise Exception("20210531 {} has no default_action".format(a))
         # generate only actors whose default_action is visible
         actors_list = [
             a for a in actors_list
-            if a.default_action.get_view_permission(user_type)]
+            if a.default_action and a.default_action.get_view_permission(user_type)]
 
         # Define every choicelist as a JS array:
         f.write("\n// ChoiceLists: \n")
@@ -742,32 +748,29 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         """
         This also manages action groups
         """
-        user_type = get_user_profile()
         buttons = []
         combo_map = dict()
         for ba in action_list:
-
-            if ba.action.show_in_bbar and ba.get_view_permission(user_type):
-                if ba.action.combo_group is None:
-                    buttons.append(self.a2btn(ba))
+            if ba.action.combo_group is None:
+                buttons.append(self.a2btn(ba))
+            else:
+                k = ba.action.combo_group
+                combo = combo_map.get(k, None)
+                if combo is None:
+                    parent = self.a2btn(ba)
+                    menu = [parent]
+                    combo = AttrDict(menu=menu)
+                    combo.update(iconCls=parent.get('iconCls'))
+                    combo.update(
+                        menu_item_text=parent.get('menu_item_text'))
+                    combo.update(text=parent.get('text'))
+                    buttons.append(combo)
+                    combo_map[k] = combo
                 else:
-                    k = ba.action.combo_group
-                    combo = combo_map.get(k, None)
-                    if combo is None:
-                        parent = self.a2btn(ba)
-                        menu = [parent]
-                        combo = AttrDict(menu=menu)
-                        combo.update(iconCls=parent.get('iconCls'))
-                        combo.update(
-                            menu_item_text=parent.get('menu_item_text'))
-                        combo.update(text=parent.get('text'))
-                        buttons.append(combo)
-                        combo_map[k] = combo
-                    else:
-                        #~ menu = parent.get('menu',None)
-                        #~ if menu is None:
-                            #~ id_map[k] = menu_btn
-                        combo['menu'].append(self.a2btn(ba))
+                    #~ menu = parent.get('menu',None)
+                    #~ if menu is None:
+                        #~ id_map[k] = menu_btn
+                    combo['menu'].append(self.a2btn(ba))
         reduced_buttons = []
         for b in buttons:
             menu = b.get('menu', None)
@@ -1069,47 +1072,55 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         yield "});"
         yield ""
 
-    def js_render_detail_action_FormPanel(self, rh, action):
+    def js_render_detail_action_FormPanel(self, rh, ba):
         rpt = rh.actor
-        #~ logger.info('20121005 js_render_detail_action_FormPanel(%s,%s)',rpt,action.full_name(rpt))
-        yield ""
-        #~ yield "// js_render_detail_action_FormPanel %s" % action
-        dtl = action.get_window_layout()
+        #~ logger.info('20121005 js_render_detail_action_FormPanel(%s,%s)',rpt,ba.full_name(rpt))
+        #~ yield "// js_render_detail_action_FormPanel %s" % ba
+        def doit(dtl):
+            yield ""
+            yield "Lino.%sPanel = Ext.extend(Lino.%s,{" % (
+                ba.full_name(), dtl._formpanel_name)
+            yield "  empty_title: %s," % py2js(ba.get_button_label())
+            if rpt.hide_navigator or ba.action.hide_navigator:
+                yield "  hide_navigator: true,"
+
+            if rh.actor.params_panel_hidden:
+                yield "  params_panel_hidden: true,"
+
+            if ba.action.save_action_name is not None:
+                yield "  save_action_name: %s," % py2js(
+                    ba.action.save_action_name)
+            yield "  ls_bbar_actions: %s," % py2js(
+                self.toolbar(rpt.get_toolbar_actions(ba.action, get_user_profile())))
+            yield "  ls_url: %s," % py2js(rpt.actor_url())
+            if ba.action != rpt.default_action.action:
+                yield "  action_name: %s," % py2js(ba.action.action_name)
+            if isinstance(ba.action, ShowInsert):
+                yield "  default_record_id: -99999,"
+
+            yield "  initComponent : function() {"
+            a = rpt.detail_action
+            if a:
+                yield "    this.ls_detail_handler = Lino.%s;" % a.full_name()
+            a = rpt.insert_action
+            if a:
+                yield "    this.ls_insert_handler = Lino.%s;" % a.full_name()
+
+            yield "    Lino.%sPanel.superclass.initComponent.call(this);" \
+                % ba.full_name()
+            yield "  }"
+            yield "});"
+            yield ""
+
+        dtl = ba.get_window_layout()
         if dtl is None:
-            raise Exception("action %s without detail?" % action.full_name())
-        yield "Lino.%sPanel = Ext.extend(Lino.%s,{" % (
-            action.full_name(), dtl._formpanel_name)
-        yield "  empty_title: %s," % py2js(action.get_button_label())
-        if rpt.hide_navigator or action.action.hide_navigator:
-            yield "  hide_navigator: true,"
-
-        if rh.actor.params_panel_hidden:
-            yield "  params_panel_hidden: true,"
-
-        if action.action.save_action_name is not None:
-            yield "  save_action_name: %s," % py2js(
-                action.action.save_action_name)
-        yield "  ls_bbar_actions: %s," % py2js(
-            self.toolbar(rpt.get_toolbar_actions(action.action, get_user_profile())))
-        yield "  ls_url: %s," % py2js(rpt.actor_url())
-        if action.action != rpt.default_action.action:
-            yield "  action_name: %s," % py2js(action.action.action_name)
-        if isinstance(action.action, ShowInsert):
-            yield "  default_record_id: -99999,"
-
-        yield "  initComponent : function() {"
-        a = rpt.detail_action
-        if a:
-            yield "    this.ls_detail_handler = Lino.%s;" % a.full_name()
-        a = rpt.insert_action
-        if a:
-            yield "    this.ls_insert_handler = Lino.%s;" % a.full_name()
-
-        yield "    Lino.%sPanel.superclass.initComponent.call(this);" \
-            % action.full_name()
-        yield "  }"
-        yield "});"
-        yield ""
+            raise Exception("20210530")
+            for dtl in rpt.extra_layouts:
+                for ln in doit(dtl):
+                    yield ln
+        else:
+            for ln in doit(dtl):
+                yield ln
 
     def js_render_GridPanel_class(self, rh):
 
@@ -1262,62 +1273,71 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             # print "20150421 {0}".format(rh)
             return
 
-        windowConfig = dict()
-        wl = ba.get_window_layout()
-        ws = ba.get_window_size()
-        #~ if wl is not None:
-            #~ ws = wl.window_size
-        if True:
-            if ws:
-                windowConfig.update(
-                    maximized=False,
-                    draggable=True,
-                    maximizable=True,
-                    modal=True)
-                # if isinstance(ws[0], basestring) and ws[0].endswith("%"):
-                #     windowConfig.update(
-                #         width=js_code('Lino.perc2width(%s)' % ws[0][:-1]))
-                if isinstance(ws[0], str):
-                    windowConfig.update(width=ws[0])
-                else:
+        name = ba.full_name()
+        def doit(wl, ws):
+            windowConfig = dict()
+            if True:
+                if ws:
                     windowConfig.update(
-                        width=js_code('Lino.chars2width(%d)' % ws[0]))
-                if ws[1] == 'auto':
-                    windowConfig.update(autoHeight=True)
-                elif isinstance(ws[1], int):
-                    #~ windowConfig.update(height=ws[1])
-                    windowConfig.update(
-                        height=js_code('Lino.rows2height(%d)' % ws[1]))
-                else:
-                    raise ValueError("height")
-                #~ print 20120629, action, windowConfig
+                        maximized=False,
+                        draggable=True,
+                        maximizable=True,
+                        modal=True)
+                    # if isinstance(ws[0], basestring) and ws[0].endswith("%"):
+                    #     windowConfig.update(
+                    #         width=js_code('Lino.perc2width(%s)' % ws[0][:-1]))
+                    if isinstance(ws[0], str):
+                        windowConfig.update(width=ws[0])
+                    else:
+                        windowConfig.update(
+                            width=js_code('Lino.chars2width(%d)' % ws[0]))
+                    if ws[1] == 'auto':
+                        windowConfig.update(autoHeight=True)
+                    elif isinstance(ws[1], int):
+                        #~ windowConfig.update(height=ws[1])
+                        windowConfig.update(
+                            height=js_code('Lino.rows2height(%d)' % ws[1]))
+                    else:
+                        raise ValueError("height")
+                    #~ print 20120629, action, windowConfig
 
-        yield "Lino.%s = new Lino.WindowAction(%s, function(){" % (
-            ba.full_name(), py2js(windowConfig))
-        #~ yield "  console.log('20120625 fn');"
-        if ba.action.extjs_main_panel:
-            yield "  return %s;" % ba.action.extjs_main_panel
-        else:
-            p = dict()
-            # if ba.action is settings.SITE.get_main_action(profile):
-            #     p.update(is_home_page=True)
-            if ba.action.hide_top_toolbar or ba.actor.hide_top_toolbar or ba.action.parameters:
-                p.update(hide_top_toolbar=True)
-            if rpt.hide_window_title:
-                p.update(hide_window_title=True)
-
-            p.update(is_main_window=True)  # workaround for problem 20111206
-            p.update(ls_url=ba.actor.actor_url())  # 20191121
-            yield "  var p = %s;" % py2js(p)
-            if params_panel:
-                if ba.action.parameters:
-                    yield "  return new Lino.%s(p);" % wl._formpanel_name
-                else:
-                    yield "  p.params_panel = new Lino.%s({});" % params_panel.layout._formpanel_name
-                    yield "  return new %s(p);" % mainPanelClass
+            # if index is not None:
+            #     name += "_" + str(index)
+            yield "Lino.%s = new Lino.WindowAction(%s, function(){" % (
+                name, py2js(windowConfig))
+            #~ yield "  console.log('20120625 fn');"
+            if ba.action.extjs_main_panel:
+                yield "  return %s;" % ba.action.extjs_main_panel
             else:
-                yield "  return new %s(p);" % mainPanelClass
-        yield "});"
+                p = dict()
+                # if ba.action is settings.SITE.get_main_action(profile):
+                #     p.update(is_home_page=True)
+                if ba.action.hide_top_toolbar or ba.actor.hide_top_toolbar or ba.action.parameters:
+                    p.update(hide_top_toolbar=True)
+                if rpt.hide_window_title:
+                    p.update(hide_window_title=True)
+
+                p.update(is_main_window=True)  # workaround for problem 20111206
+                p.update(ls_url=ba.actor.actor_url())  # 20191121
+                yield "  var p = %s;" % py2js(p)
+                if params_panel:
+                    if ba.action.parameters:
+                        yield "  return new Lino.%s(p);" % wl._formpanel_name
+                    else:
+                        yield "  p.params_panel = new Lino.%s({});" % params_panel.layout._formpanel_name
+                        yield "  return new %s(p);" % mainPanelClass
+                else:
+                    yield "  return new %s(p);" % mainPanelClass
+            yield "});"
+
+        wl = ba.get_window_layout()
+        # Note that wl may be None (if ba.action.extjs_main_panel is True)
+        for ln in doit(wl, ba.get_window_size()):
+            yield ln
+
+        for xwl in ba.actor.extra_layouts:
+            for ln in doit(xwl, xwl.window_size):
+                yield ln
 
 
     def linolib_intro(self):
