@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2009-2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 
@@ -32,13 +32,14 @@ from os import environ
 from django import http
 from django.db import models
 from django.conf import settings
+from django.core.exceptions import PermissionDenied
 from django.views.generic import View
+from django.views.generic.base import TemplateView
 from django.views.decorators.cache import never_cache
 from django.utils.decorators import method_decorator
-
 from django.views.decorators.csrf import ensure_csrf_cookie, csrf_protect
-from django.utils.translation import ugettext as _
-from django.utils.encoding import force_text
+from django.utils.translation import gettext as _
+from django.utils.encoding import force_str
 from lino.core import auth
 
 from lino.core.signals import pre_ui_delete
@@ -153,83 +154,30 @@ class MainHtml(View):
     def get(self, request, *args, **kw):
         # ~ logger.info("20130719 MainHtml")
         settings.SITE.startup()
-        ui = settings.SITE.kernel
         # ~ raise Exception("20131023")
         ar = BaseRequest(request)
         html = settings.SITE.get_main_html(
-            request, extjs=settings.SITE.plugins.extjs)
+            request, front_end=settings.SITE.plugins.extjs)
         html = settings.SITE.plugins.extjs.renderer.html_text(html)
         ar.success(html=html)
         ar.set_response(**test_version_mismatch(request))
-        return ui.default_renderer.render_action_response(ar)
+        return settings.SITE.kernel.default_renderer.render_action_response(ar)
 
 
-class unused_Authenticate(View):
-    """This view is being used when :setting:`remote_user_header` is
-    empty (and :setting:`user_model` not).
-    :class:`lino.core.auth.SessionUserMiddleware`
-
-    """
-
-    def get(self, request, *args, **kw):
-        action_name = request.GET.get(constants.URL_PARAM_ACTION_NAME)
-        if action_name == 'logout':
-            username = request.session.pop('username', None)
-            auth.logout(request)
-            # request.session.pop('password', None)
-            # ~ username = request.session['username']
-            # ~ del request.session['password']
-
-            ar = BaseRequest(request)
-            ar.success("User %r logged out." % username)
-            return ar.renderer.render_action_response(ar)
-        raise http.Http404()
-
-    @method_decorator(csrf_protect)
-    def post(self, request, *args, **kw):
-        username = request.POST.get('username')
-        password = request.POST.get('password')
-        user = auth.authenticate(
-            request, username=username, password=password)
-        if user is not None:
-            # user.is_authenticated:
-            auth.login(request, user)
-
-        ar = BaseRequest(request)
-        # mw = auth.get_auth_middleware()
-        # msg = mw.authenticate(username, password, request)
-        # if msg:
-        #     request.session.pop('username', None)
-        #     ar.error(msg)
-        # else:
-        #     request.session['username'] = username
-        #     # request.session['password'] = password
-        # ar.success(("Now logged in as %r" % username))
-        #     # print "20150428 Now logged in as %r (%s)" % (username, user)
-        if user is None:
-            ar.error(_("Failed to log in as {}.".format(username)))
-        else:
-            ar.success(("Now logged in as %r" % username))
-        return ar.renderer.render_action_response(ar)
+class SWView(TemplateView):
+    template_name = 'extjs/service-worker.js'
+    content_type = 'application/javascript'
 
 
 class RunJasmine(View):
-    """
-    """
-
     def get(self, request, *args, **kw):
-        ui = settings.SITE.kernel
         return http.HttpResponse(
-            ui.extjs_renderer.html_page(request, run_jasmine=True))
+            settings.SITE.kernel.extjs_renderer.html_page(request, run_jasmine=True))
 
 
 class EidAppletService(View):
-    """
-    """
-
     def post(self, request, *args, **kw):
-        ui = settings.SITE.kernel
-        return ui.success(html='Hallo?')
+        return settings.SITE.kernel.success(html='Hallo?')
 
 
 # class Callbacks(View):
@@ -364,25 +312,26 @@ class ApiElement(View):
     @method_decorator(ensure_csrf_cookie)
     def get(self, request, app_label=None, actor=None, pk=None):
         # this is also used by the react front end
-        ui = settings.SITE.kernel
         rpt = requested_actor(app_label, actor)
         # if not rpt.get_view_permission(request.user.user_type):
         #     raise PermissionDenied("{} has permission to view {}".format(
         #         request.user.user_type, rpt))
-        # print(rpt, request.user.user_type)
+        # print("20210530", rpt, request.user.user_type)
 
-        action_name = request.GET.get(constants.URL_PARAM_ACTION_NAME,
-                                      rpt.default_elem_action_name)
-        ba = rpt.get_url_action(action_name)
-        if ba is None:
-            raise http.Http404("%s has no action %r" % (rpt, action_name))
+        action_name = request.GET.get(constants.URL_PARAM_ACTION_NAME, None)
+        if action_name:
+            ba = rpt.get_url_action(action_name)
+            if ba is None:
+                raise http.Http404("%s has no action %r" % (rpt, action_name))
+        else:
+            ba = rpt.detail_action
+            if ba is None:
+                raise http.Http404("%s has no detail_action" % rpt)
 
         if pk and pk != '-99999' and pk != '-99998':
-            # ~ ar = ba.request(request=request,selected_pks=[pk])
-            # ~ print 20131004, ba.actor
             # Use url selected rows as selected PKs if defined, otherwise use the PK defined in the url path
             sr = request.GET.getlist(constants.URL_PARAM_SELECTED)
-            if not sr:
+            if len(sr) == 0:
                 sr = [pk]
             ar = ba.request(request=request, selected_pks=sr)
             # print(
@@ -396,9 +345,7 @@ class ApiElement(View):
             ar = ba.request(request=request)
             elem = None
 
-        # ar.renderer = ui.extjs_renderer
-        ar.renderer = ui.default_renderer
-        ah = ar.ah
+        ar.renderer = settings.SITE.kernel.default_renderer
 
         if not ar.get_permission():
             msg = "No permission to run {}".format(ar)
@@ -408,14 +355,13 @@ class ApiElement(View):
         fmt = request.GET.get(
             constants.URL_PARAM_FORMAT, ba.action.default_format)
         if ba.action.opens_a_window:
-
             if fmt == constants.URL_FORMAT_JSON:
                 if pk == '-99999':
                     elem = ar.create_instance()
-                    datarec = ar.elem2rec_insert(ah, elem)
+                    datarec = ar.elem2rec_insert(ar.ah, elem)
                 elif pk == '-99998':
                     elem = ar.create_instance()
-                    datarec = elem2rec_empty(ar, ah, elem)
+                    datarec = elem2rec_empty(ar, ar.ah, elem)
                 elif elem is None:
                     datarec = dict(
                         success=False, message=NOT_FOUND % (rpt, pk))
@@ -436,12 +382,6 @@ class ApiElement(View):
                     on_ready=ar.renderer.action_call(
                         request, ba, after_show)))
 
-        # if isinstance(ba.action, actions.RedirectAction):
-        #     target = ba.action.get_target_url(elem)
-        #     if target is None:
-        #         raise http.Http404("%s failed for %r" % (ba, elem))
-        #     return http.HttpResponseRedirect(target)
-
         if pk == '-99998':
             assert elem is None
             elem = ar.create_instance()
@@ -461,6 +401,8 @@ class ApiElement(View):
             ar.selected_rows = [elem]
         else:
             ar.set_selected_pks(pk)
+        # print("20210212 ApiElement.post()", ar, pk, ar.selected_rows)
+        # print("20210212 ApiElement.post()", request.POST)
         return settings.SITE.kernel.run_action(ar)
 
     @method_decorator(csrf_protect)
@@ -482,13 +424,6 @@ class ApiElement(View):
         ar.set_selected_pks(pk)
         return settings.SITE.kernel.run_action(ar)
 
-    def old_delete(self, request, app_label=None, actor=None, pk=None):
-        rpt = requested_actor(app_label, actor)
-        ar = rpt.request(request=request)
-        ar.set_selected_pks(pk)
-        elem = ar.selected_rows[0]
-        return delete_element(ar, elem)
-
 
 class ApiList(View):
     @method_decorator(csrf_protect)
@@ -564,9 +499,7 @@ class ApiList(View):
                     ar.request,
                     ar.bound_action, after_show))
             # ~ print '20110714 on_ready', params
-
             kw.update(title=ar.get_title())
-
             return http.HttpResponse(ar.renderer.html_page(request, **kw))
 
         if fmt == 'csv':
@@ -600,7 +533,7 @@ class ApiList(View):
                                 MAX_ROW_COUNT)
             response = http.HttpResponse(
                 content_type='text/html;charset="utf-8"')
-            doc = Document(force_text(ar.get_title()))
+            doc = Document(force_str(ar.get_title()))
             doc.body.append(E.h1(doc.title))
             t = doc.add_table()
             # ~ settings.SITE.kernel.ar2html(ar,t,ar.data_iterator)
@@ -609,42 +542,3 @@ class ApiList(View):
             return response
 
         return settings.SITE.kernel.run_action(ar)
-
-
-class GridConfig(View):
-
-    @method_decorator(csrf_protect)
-    def put(self, request, app_label=None, actor=None):
-        rpt = requested_actor(app_label, actor)
-        PUT = http.QueryDict(request.body)  # raw_post_data before Django 1.4
-        gc = dict(
-            widths=[int(x)
-                    for x in PUT.getlist(constants.URL_PARAM_WIDTHS)],
-            columns=[str(x)
-                     for x in PUT.getlist(constants.URL_PARAM_COLUMNS)],
-            hiddens=[(x == 'true')
-                     for x in PUT.getlist(constants.URL_PARAM_HIDDENS)],
-            # ~ hidden_cols=[str(x) for x in PUT.getlist('hidden_cols')],
-        )
-
-        filter = PUT.get('filter', None)
-        if filter is not None:
-            filter = json.loads(filter)
-            gc['filters'] = [constants.dict2kw(flt) for flt in filter]
-
-        name = PUT.get('name', None)
-        if name is None:
-            name = constants.DEFAULT_GC_NAME
-        else:
-            name = int(name)
-
-        gc.update(label=PUT.get('label', "Standard"))
-        try:
-            msg = rpt.save_grid_config(name, gc)
-        except IOError as e:
-            msg = _("Error while saving GC for %(table)s: %(error)s") % dict(
-                table=rpt, error=e)
-            return settings.SITE.kernel.error(None, msg, alert=True)
-        # ~ logger.info(msg)
-        settings.SITE.kernel.extjs_renderer.build_site_cache(True)
-        return settings.SITE.kernel.success(msg)
