@@ -146,7 +146,7 @@ def table2html(ar, as_main=True):
     buttons.append(('>>', _("Last page"), last_url))
 
     return E.div(buttons2pager(buttons), t.as_element())
-        
+
 
 def layout2html(ar, elem):
 
@@ -224,13 +224,13 @@ class Element(View):
             elem = None
 
         main = layout2html(ar, elem)
-       
+
         # The `method="html"` argument isn't available in Python 2.6,
         # only 2.7.  It is useful to avoid side effects in case of
         # empty elements: the default method (xml) writes an empty
         # E.div() as "<div/>" while in HTML5 it must be "<div></div>"
         # (and the ending / is ignored).
-        
+
         #~ return tostring(main, method="html")
         #~ return tostring(main)
         # return main
@@ -257,7 +257,7 @@ class Authenticate(View):
             #~ del request.session['password']
             target = '/'
             return http.HttpResponseRedirect(target)
-            
+
 
             # ar = BaseRequest(request)
             # ar.success("User %r logged out." % username)
@@ -286,7 +286,7 @@ class Authenticate(View):
         #     # print "20150428 Now logged in as %r (%s)" % (username, user)
         # return ar.renderer.render_action_response(ar)
 
-        
+
 class Index(View):
     """
     Render the main page.
@@ -306,7 +306,7 @@ class Index(View):
 def index_response(ar):
     ui = settings.SITE.plugins.bootstrap3
 
-    main = settings.SITE.get_main_html(ar.request, extjs=ui)
+    main = settings.SITE.get_main_html(ar.request, front_end=ui)
     main = ui.renderer.html_text(main)
     context = dict(
         title=settings.SITE.title,
