@@ -1,5 +1,5 @@
 # Copyright 2015-2019 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Adds printing functionality to a Lino application.
 See :doc:`/specs/printing`.
@@ -7,7 +7,7 @@ See :doc:`/specs/printing`.
 """
 
 from lino.api import ad
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class Plugin(ad.Plugin):
