@@ -2,6 +2,7 @@
 # Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
+from etgen.html import E
 from django.conf import settings
 from django.utils.encoding import force_str
 
@@ -14,13 +15,14 @@ from lino.api import dd, rt
 from lino.core import actions
 from lino.core.utils import full_model_name
 from lino.core.roles import SiteStaff
+from lino.core.actors import resolve_action
 
 from lino.modlib.printing.choicelists import BuildMethods
 from lino.modlib.checkdata.choicelists import Checker
 
 
 # import them here to have them on rt.models.system:
-from .choicelists import YesNo, Genders, PeriodEvents
+from .choicelists import YesNo, Genders, PeriodEvents, DashboardLayouts
 from .mixins import Lockable
 
 
@@ -108,6 +110,13 @@ dd.connection_created.connect(my_handler)
 models.signals.post_migrate.connect(my_handler)
 
 
+# def dashboard_layouts(cls, k, layout_class, **options):
+#     assert k == "detail_layout"
+#     yield cls.detail_layout
+#     for i in DashboardLayouts.get_list_items():
+#         yield i.main
+
+
 class SiteConfigs(dd.Table):
 
     model = 'system.SiteConfig'
@@ -127,12 +136,90 @@ class SiteConfigs(dd.Table):
 
     do_build = BuildSiteCache()
 
+from lino.utils.report import EmptyTable
+
+
+class Dashboard(EmptyTable):
+
+    # label = _("D")
+    hide_navigator = True
+    required_roles = set()
+    allow_delete = False
+    # detail_layout = """
+    # welcome_messages
+    # working.WorkedHours comments.RecentComments
+    # tickets.MyTicketsToWork
+    # notify.MyMessages
+    # """
+
+    @classmethod
+    def get_extra_layouts(cls):
+        # count = 0
+        for i in DashboardLayouts.get_list_items():
+            yield i.value, i.main
+            # print("20210530", i.value, repr(i.main))
+        #     count += 1
+        # assert count > 0
+
+    @classmethod
+    def get_default_action(cls):
+        # raise Exception("20210530")
+        # return None
+        # return actions.ShowExtraDetail(None)
+        # cls._bind_action("extra_"+name, a, False)
+        ba = cls.get_action_by_name('extra_default')
+        # assert ba is not None
+        return ba
+
+    @classmethod
+    def get_detail_action(self, ar):
+        u = ar.get_user()
+        if u.dashboard_layout:
+            return cls.get_action_by_name('extra_' + u.dashboard_layout.name)
+        return cls.get_action_by_name('extra_default')
+
+    @dd.htmlbox()
+    def welcome_messages(cls, obj, ar=None):
+        return settings.SITE.get_main_html(ar.request)
+        # if ar.get_user().is_authenticated:
+        #     return E.p(*settings.SITE.get_welcome_messages(ar))
+
+    @classmethod
+    def collect_extra_actions(cls):
+        return settings.SITE.quicklinks.items
+        # for ql in settings.SITE.quicklinks.items:
+        #     yield ql.bound_action
+
+        # for mi in settings.SITE.get_quicklinks(None).items:
+        #     yield mi
+        # for p in settings.SITE.sorted_plugins:
+        #     for ql in p.get_quicklinks(None):
+        #         yield ql
+        #         # print(repr(ql))
+        #         # ba = resolve_action(ql)
+        #         # if ba is not None:
+        #         #     yield ba
+
 
 # if settings.SITE.user_model == 'users.User':
 #     dd.inject_field(settings.SITE.user_model,
 #                     'user_type', UserTypes.field())
 #     dd.inject_field(settings.SITE.user_model, 'language', dd.LanguageField())
 
+# @dd.receiver(dd.pre_analyze)
+# def set_dashboard_actions(sender, **kw):
+#     for p in settings.SITE.sorted_plugins:
+#         for ql in p.get_quicklinks(None):
+#             ba = resolve_action(ql)
+#             Dashboard.define_action(ba.action.action_name=ba)
+
+    # for ql in settings.SITE.get_quicklinks()
+    # for m in get_checkable_models().keys():
+    #     if m is None:
+    #         continue
+    #     assert m is not Problem
+    #     m.define_action(check_data=UpdateProblemsByController(m))
+    #     m.define_action(fix_problems=FixProblemsByController(m))
 
 
 class BleachChecker(Checker):
