@@ -14,6 +14,7 @@ from lino.core import auth, layouts
 from lino.core.actions import SubmitInsert
 
 
+
 class CheckedSubmitInsert(SubmitInsert):
     """Like the standard :class:`lino.core.actions.SubmitInsert`, but
     checks certain things before accepting the new user.
@@ -92,6 +93,21 @@ class VerifyUser(dd.Action):
         ar.success(_("User {} is now verified.").format(user))
 
 
+class MySettings(dd.Action):
+    label = _("My settings")
+    select_rows = False
+    show_in_bbar = False
+    # http_method = "POST"
+    default_format = None
+
+    def run_from_ui(self, ar, **kw):
+        # assert len(ar.selected_rows) == 1
+        # user = ar.selected_rows[0]
+        user = ar.get_user()
+        ar.goto_instance(user)
+        ar.success("OK")
+
+
 class SendWelcomeMail(dd.Action):
     label = _("Welcome mail")
     if True:  # #1336
