@@ -19,9 +19,11 @@ from .choicelists import UserTypes
 from .mixins import UserAuthored  #, TimezoneHolder
 from .actions import ChangePassword, SignOut, VerifyUser, CheckedSubmitInsert
 from .actions import SendWelcomeMail
+from .actions import MySettings
 # from .actions import SignIn
 from lino.core.auth.utils import AnonymousUser
 from lino.modlib.about.choicelists import TimeZones, DateFormats
+from lino.modlib.system.choicelists import DashboardLayouts
 from lino.modlib.printing.mixins import Printable
 
 from lino.core.roles import Supervisor
@@ -106,12 +108,14 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
         time_zone = dd.DummyField()
 
     date_format = DateFormats.field(default='default')
+    dashboard_layout = DashboardLayouts.field(blank=True, null=True)
 
     submit_insert = CheckedSubmitInsert()
     send_welcome_email = SendWelcomeMail()
     change_password = ChangePassword()
     # sign_in = SignIn()
     sign_out = SignOut()
+    my_settings = MySettings()
 
     def __str__(self):
         return self.get_full_name()
